function [R,Z,f] = CartaRZInf(N,beta,a,b,tau0,L)
%function [R,Z,f] = CartaRZInf(N,beta,a,b,tau0,L) nos va a generar una carta de puntos (R,Z) en el instante que yo le diga
%utilizando como parametros:

%   N:     Numero de puntos a utilizar
%   beta:  Parametro beta de la gaussiana que vamos a utilizar como perfil.
%   a:     Hace referencia a la altura maxima del cilindro
%   b:     Hace referencia a la distancia radial maxima del sistema que vamos a estudiar
%   tau0:  Instante en el que voy a considerar el campo escalar de temperaturas.
%   L:     Numero de lineas de contorno que quiero que represente en la grafica en cuestion

%En este primer programa tomamos el perfil de temperaturas en el instante inicial como independiente de Z y theta. La dependencia
%radial de dicha distribucion la estamos suponiendo gaussiana de parametro beta.

    [Am,betam] = coefAs(N,beta,b);

%Queremos obtener los valores de la funcion de temperatura para distintos valores de R y Z, barriendo un amplio
%margen del disco

    B=0;i=1;k=1;

    for Z=0.01:0.01:a
        for R=0:0.01:b
        
            for n=1:1:N
                B = B + Am(n)*besselJ(0,betam(n)*R)*exp(-1*tau0*betam(n)^2);
            end
        
            f(k,i) = B*erf(Z/sqrt(4*tau0));
            i=i+1;
            B = 0;
        end
        k = k + 1;
        i=1;
    end
 
 %Una vez generada la carta devolvamos tambien los datos de R y Z por si se requiere alguna representacion adimensional.
 
    R=0:0.01:b;
    Z=0.01:0.01:a;
    
    h = contour(R,Z,f,L);
    clabel(h);title('Carta R,Z en el el instante tau=0.07');